==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/plugins/history/model/sms-dates-model.h <==
/*
 * %kadu copyright begin%
 * Copyright 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SMS_DATES_MODEL_H
#define SMS_DATES_MODEL_H

#include <QtCore/QAbstractListModel>
#include <QtCore/QDate>
#include <QtCore/QList>

#include "buddies/buddy.h"

class DatesModelItem;

class SmsDatesModel : public QAbstractListModel
{
	Q_OBJECT

	QString Recipient;
	QList<DatesModelItem> Dates;

public:
	SmsDatesModel(const QString &recipient, const QList<DatesModelItem> &dates, QObject *parent = 0);
	virtual ~SmsDatesModel();

	virtual int columnCount(const QModelIndex &parent) const;
	virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;

	virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
	virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;

	void setRecipient(const QString &recipient);
	void setDates(const QList<DatesModelItem> &dates);

	QModelIndex indexForDate(const QDate &date);

};

#endif // SMS_DATES_MODEL_H

==> kadu_0.11.0~rc2.orig.tar.bz2: kadu-0.11.0-rc2/plugins/history/model/sms-dates-model.h <==
/*
 * %kadu copyright begin%
 * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SMS_DATES_MODEL_H
#define SMS_DATES_MODEL_H

#include <QtCore/QAbstractListModel>
#include <QtCore/QDate>
#include <QtCore/QVector>

#include "buddies/buddy.h"

struct DatesModelItem;

class SmsDatesModel : public QAbstractListModel
{
	Q_OBJECT

	QString Recipient;
	QVector<DatesModelItem> Dates;

public:
	SmsDatesModel(const QString &recipient, const QVector<DatesModelItem> &dates, QObject *parent = 0);
	virtual ~SmsDatesModel();

	virtual int columnCount(const QModelIndex &parent) const;
	virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;

	virtual QVariant headerData(int section, Qt::Orientation orientation, int role) const;
	virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;

	void setRecipient(const QString &recipient);
	void setDates(const QVector<DatesModelItem> &dates);

	QModelIndex indexForDate(const QDate &date);

};

#endif // SMS_DATES_MODEL_H
